<!DOCTYPE gui SYSTEM "kpartgui.dtd">
<gui name="callgraphtab" version="1">

<MenuBar>
<Menu name="view">
    <Action name="zoomIn"/>
    <Action name="zoomOut"/>
    <Action name="focusExpensive"/>
</Menu>
</MenuBar>

<ToolBar name="callgraphToolBar">
    <text>CallGraph Toolbar</text>
    <Action name="zoomIn"/>
    <Action name="zoomOut"/>
    <Action name="focusExpensive"/>
</ToolBar>

</gui>
